@@ -12,7 +12,9 @@ check_can_create_state_output_file <- function( # nolint indeed a long function
 ) {
   beastier::check_beast2_options(beast2_options)
   beastier::check_can_create_dir_for_state_output_file(beast2_options)
-  if (file.exists(beast2_options$output_state_filename)) return()
+  if (file.exists(beast2_options$output_state_filename)) {
+    return(invisible(beast2_options))
+  }
 
   dir.create(
     path = dirname(beast2_options$output_state_filename),
@@ -33,4 +35,5 @@ check_can_create_state_output_file <- function( # nolint indeed a long function
       )
     }
   )
+  invisible(beast2_options)
 }
