@@ -19,7 +19,7 @@ extract_treelog_filename_from_beast2_input_file <- function( # nolint indeed a l
   input_filename
 ) {
   testthat::expect_true(file.exists(input_filename))
-  text <- readr::read_lines(input_filename)
+  text <- readr::read_lines(input_filename, progress = FALSE)
   treelog_line <- stringr::str_subset(
     string = text,
     pattern = "<logger id=\"treelog.t:"
